#!/bin/sh

# All env in this default.env can be overridden by env.local.

# All env in this default.env must NOT depend on any other env.  If they do, they
# must use single quotes to avoid early expansion before overrides in env.local
# are applied and must be added to the list of DELAYED_EVAL.

# Any default value that should be marked for security concern or recommended modificiation should
# use the '${__DEFAULT__{var}}' naming format. These can then be referenced in 'env.local.example' to
# avoid literal value duplication, and ensure they remain in sync. Also, those '${__DEFAULT__{var}}'
# definitions should *NOT* be exported to avoid unnecessary polution of the environment variables.
# Variables with format '${__DEFAULT__{var}}' will be flagged accordingly to their required/optional status
# (see also: 'check_default_vars' in 'birdhouse/read-configs.include.sh').

export BASH_IMAGE="bash:5.1.4"

# Root directory under which all data persistence should be nested under
export DATA_PERSIST_ROOT="/data"

# shellcheck disable=SC2016
# Root directory for all files that are persisted on disk and may contain links (ie. the files
# are "shared" between subdirectories).
export DATA_PERSIST_SHARED_ROOT='${DATA_PERSIST_ROOT}'

# Log directory used for the various scheduler tasks
# TODO: use this variable for other references of the log path (only used in the pavics-jupyter-base's .env file for now)
export PAVICS_LOG_DIR=/var/log/PAVICS

# Allow different public and internal hostname.
# Default to PAVICS_FQDN, which must be set in env.local.
# Must use single-quote for delayed eval.
export PAVICS_FQDN_PUBLIC='${PAVICS_FQDN}'

# Append to DELAYED_EVAL list.
export DELAYED_EVAL="
  $DELAYED_EVAL
  PAVICS_FQDN_PUBLIC
  DOC_URL
  SUPPORT_EMAIL
  SSL_CERTIFICATE
  DATA_PERSIST_SHARED_ROOT
  WPS_OUTPUTS_DIR
  SERVER_NAME
  SERVER_DESCRIPTION
  SERVER_INSTITUTION
  SERVER_SUBJECT
  SERVER_TAGS
  SERVER_DOCUMENTATION_URL
  SERVER_RELEASE_NOTES_URL
  SERVER_SUPPORT_URL
  SERVER_LICENSE_URL
"

# Server Identification Details
#   Following definitions should definitenly be updated.
#   Previous defaults are defined for backward-compatibility.
#   If not overridden explicitly by their non '__' prefixed variant,
#   a WARN message will be displayed by pavics-compose.
__DEFAULT__SERVER_NAME="PAVICS"
__DEFAULT__SERVER_DESCRIPTION="
The PAVICS (Power Analytics for Visualization of Climate Science) platform is a collection of
climate analysis services served through Open Geospatial Consortium (OGC) protocols.
These services include data access, processing and visualization. Both data and algorithms
can be accessed either programmatically, through OGC-compliant clients such as QGIS or ArcGIS,
or a custom web interface.
"
__DEFAULT__SERVER_INSTITUTION="Ouranos"
__DEFAULT__SERVER_SUBJECT="Climatology"
# below can be a CSV list of tags
__DEFAULT__SERVER_TAGS="Climatology"
__DEFAULT__SERVER_DOCUMENTATION_URL="https://pavics-sdi.readthedocs.io/en/latest/arch/backend.html"
__DEFAULT__SERVER_RELEASE_NOTES_URL="https://github.com/bird-house/birdhouse-deploy/blob/master/CHANGES.md"
__DEFAULT__SERVER_SUPPORT_URL="https://github.com/bird-house/birdhouse-deploy/issues"
# NOTE:
#   This value does not use the previously hard coded default.
#   Previous default pointed at the wrong repository with a mismatching LICENSE file.
__DEFAULT__SERVER_LICENSE_URL="https://github.com/bird-house/birdhouse-deploy/blob/master/LICENSE"
__DEFAULT__SUPPORT_EMAIL="helpdesk@example.com"
__DEFAULT__DOC_URL="https://www.example.com/"
__DEFAULT__PAVICS_FQDN="hostname.domainname"
__DEFAULT__SSL_CERTIFICATE="/path/to/ssl/cert.pem"

# apply overrides or fallback above defaults with delayed evaluation
# exceptions for 'SUPPORT_EMAIL' and 'DOC_URL' using the old name for backward compatibility.
export SUPPORT_EMAIL='${__DEFAULT__SUPPORT_EMAIL}'
export DOC_URL='${__DEFAULT__DOC_URL}'
export SSL_CERTIFICATE='${__DEFAULT__SSL_CERTIFICATE}'
export SERVER_NAME='${__DEFAULT__SERVER_NAME}'
export SERVER_DESCRIPTION='${__DEFAULT__SERVER_DESCRIPTION}'
export SERVER_INSTITUTION='${__DEFAULT__SERVER_INSTITUTION}'
export SERVER_SUBJECT='${__DEFAULT__SERVER_SUBJECT}'
export SERVER_TAGS='${__DEFAULT__SERVER_TAGS}'
export SERVER_DOCUMENTATION_URL='${__DEFAULT__SERVER_DOCUMENTATION_URL}'
export SERVER_RELEASE_NOTES_URL='${__DEFAULT__SERVER_RELEASE_NOTES_URL}'
export SERVER_SUPPORT_URL='${__DEFAULT__SERVER_SUPPORT_URL}'
export SERVER_LICENSE_URL='${__DEFAULT__SERVER_LICENSE_URL}'

# Defaults for required variables recommended for override for security reasons.
# Those will not be set explicitly as defaults to ensure they are overridden explicitly by the instance.
# These values would be detected only if the instance was configured using a copy of 'env.local.example'.
__DEFAULT__MAGPIE_SECRET="itzaseekrit"
__DEFAULT__MAGPIE_ADMIN_USERNAME="admin"
__DEFAULT__MAGPIE_ADMIN_PASSWORD="qwertyqwerty!"
__DEFAULT__POSTGRES_PAVICS_USERNAME="postgres-pavics"
__DEFAULT__POSTGRES_PAVICS_PASSWORD="postgres-qwerty"
__DEFAULT__POSTGRES_MAGPIE_USERNAME="postgres-magpie"
__DEFAULT__POSTGRES_MAGPIE_PASSWORD="postgres-qwerty"
__DEFAULT__GEOSERVER_ADMIN_USER="admingeo"
__DEFAULT__GEOSERVER_ADMIN_PASSWORD="geoserverpass"
#############################################################################
# Deprecated vars (for components in the ./deprecated-components directory)
#############################################################################
__DEFAULT__TOMCAT_NCWMS_PASSWORD="ncwmspass"
__DEFAULT__CATALOG_USERNAME="admin-catalog"
__DEFAULT__CATALOG_PASSWORD="qwerty"
__DEFAULT__PHOENIX_PASSWORD="phoenix_pass"
__DEFAULT__PHOENIX_PASSWORD_HASH="sha256:123456789012:1234567890123456789012345678901234567890123456789012345678901234"

export DEFAULT_CONF_DIRS='
  ./components/proxy
  ./components/magpie
  ./components/twitcher
  ./components/cowbird
  ./components/stac
'

export USER_WORKSPACE_UID=1000
export USER_WORKSPACE_GID=1000

export WPS_OUTPUTS_DIR='${DATA_PERSIST_SHARED_ROOT}/wps_outputs'
